package top.qaqaq.service.impl;

import top.qaqaq.dao.BookDao;
import top.qaqaq.dao.OrderDao;
import top.qaqaq.dao.OrderItemDao;
import top.qaqaq.dao.impl.BookDaoImpl;
import top.qaqaq.dao.impl.OrderDaoImpl;
import top.qaqaq.dao.impl.OrderItemDaoImpl;
import top.qaqaq.pojo.*;
import top.qaqaq.service.OrderService;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * @author RichieZhang
 * @create 2022-12-14 下午 5:40
 */
public class OrderServiceImpl implements OrderService {

    private OrderDao orderDao = new OrderDaoImpl();
    private OrderItemDao orderItemDao = new OrderItemDaoImpl();
    private BookDao bookDao = new BookDaoImpl();

    @Override
    public String createOrder(Cart cart, Integer userId) {

        // 订单号===唯一性
        String orderId = System.currentTimeMillis() + "" + userId;
        // 创建一个订单对象
        Order order = new Order(orderId,LocalDateTime.now(),cart.getTotalPrice(),0,userId);
        // 保存订单
        orderDao.saveOrder(order);

        // 遍历购物车中每一个商品项转换成为订单项保存到数据库
        for (Map.Entry<Integer, CartItem> entry : cart.getItems().entrySet()) {
            // 获取每一个购物车中的商品项
            CartItem cartItem = entry.getValue();
            // 转换为每一个订单项
            OrderItem orderItem = new OrderItem(null,cartItem.getName(),cartItem.getCount(),cartItem.getPrice(),cartItem.getTotalPrice(),orderId);
            // 保存订单项到书库
            orderItemDao.saveOrderItem(orderItem);

            // 更新库存和销量
            Book book = bookDao.queryBookById(cartItem.getId());
            book.setSales(book.getSales() + cartItem.getCount());
            book.setStock(book.getStock() - cartItem.getCount());
            bookDao.updateBook(book);
        }

        // 清空购物车
        cart.clear();

        return orderId;
    }

    @Override
    public List<Order> showAllOrders() {

        return orderDao.queryOrders();

    }

    @Override
    public int sendOrder(String orderId) {

        return orderDao.changeOrderStatus(orderId,1);
    }

    @Override
    public List<OrderItem> showOrderDetail(String orderId) {

        return orderItemDao.queryOrderItemByOrderId(orderId);

    }

    @Override
    public List<Order> showMyOrders(Integer userId) {

        return orderDao.queryOrdersByUserId(userId);

    }

    @Override
    public int receiverOrder(String orderId) {

        return orderDao.changeOrderStatus(orderId, 2);
    }
}
