package top.qaqaq.web;

import jakarta.servlet.ServletException;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import top.qaqaq.pojo.Order;
import top.qaqaq.pojo.OrderItem;
import top.qaqaq.pojo.User;
import top.qaqaq.service.OrderService;
import top.qaqaq.service.impl.OrderServiceImpl;

import java.io.IOException;
import java.util.List;

/**
 * @author RichieZhang
 * @create 2022-12-14 下午 9:31
 */
public class ClientOrderServlet extends BaseServlet{

    private OrderService orderService = new OrderServiceImpl();

    /**
     * 查看我的订单
     * @param req
     * @param resp
     * @throws ServletException
     * @throws IOException
     */
    protected void showMyOrders(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {

        // 获取用户Id
        User loginUser = (User) req.getSession().getAttribute("user");

        Integer userId = loginUser.getId();

        //  查询数据
        List<Order> myOrders = orderService.showMyOrders(userId);

        // 保存到request域中
        req.setAttribute("myOrders",myOrders);

        // 请求转发
        req.getRequestDispatcher("/pages/order/order.jsp").forward(req,resp);

    }

    /**
     * 查看订单详情
     * @param req
     * @param resp
     * @throws ServletException
     * @throws IOException
     */
    protected void showOrderDetail(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {

        // 查找图书的orderId
        String orderId = req.getParameter("orderId");

        // 查询数据
        List<OrderItem> orderItems = orderService.showOrderDetail(orderId);

        // 保存到request域中
        req.setAttribute("orderItems",orderItems);

        //请求转发
        req.getRequestDispatcher("/pages/order/orderItem.jsp").forward(req,resp);

    }

    /**
     * 签收订单/确认收货
     * @param req
     * @param resp
     * @throws ServletException
     * @throws IOException
     */
    protected void receiverOrder(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {

        // 查找图书的orderId
        String orderId = req.getParameter("orderId");

        // 签收
        orderService.receiverOrder(orderId);

        // 重定向
        resp.sendRedirect(req.getHeader("referer"));
    }
}
